package jalview.analysis.scoremodels;

import jalview.api.analysis.ScoreModelI;
import jalview.datamodel.AlignmentView;
import jalview.util.Comparison;

public class PIDScoreModel implements ScoreModelI
{

  @Override
  public float[][] findDistances(AlignmentView seqData)
  {
    String[] sequenceString = seqData
            .getSequenceStrings(Comparison.GapChars.charAt(0));
    int noseqs = sequenceString.length;
    float[][] distance = new float[noseqs][noseqs];
    for (int i = 0; i < (noseqs - 1); i++)
    {
      for (int j = i; j < noseqs; j++)
      {
        if (j == i)
        {
          distance[i][i] = 0;
        }
        else
        {
          distance[i][j] = 100 - Comparison.PID(sequenceString[i],
                  sequenceString[j]);

          distance[j][i] = distance[i][j];
        }
      }
    }
    return distance;
  }

  @Override
  public String getName()
  {
    return "PID";
  }

  @Override
  public boolean isDNA()
  {
    return true;
  }

  @Override
  public boolean isProtein()
  {
    return true;
  }

}
